Nox - Flexible test automation for Python
=========================================

``nox`` is a command-line tool that automates testing in multiple Python
environments, similar to `tox`_. Unlike tox, Nox uses a standard Python
file for configuration.

The latest documentation is available on `Read the Docs`_.

The source code is available on `GitHub`_.


.. _tox: https://tox.readthedocs.io
.. _Read the Docs: https://nox.readthedocs.io
.. _GitHub: https://github.com/theacodes/nox
